@@ -422,6 +422,15 @@ class Interval():
         """
         return self.Right - self.Left
 
+    
+    def midpoint(self):
+        """
+        Returns midpoint of interval
+        (self.Left+self.Right)/2
+        """
+        
+        return (self.Left+self.Right)/2
+    
     # def mean(*args):
     #     LSum = 0
     #     USum = 0
